% Sea-Surface Temperature (SST) Remapping Package
%
% A collection of routines to process SST data for HOPS.  SST can come from
% 2 basic sources:
%
%    Johns Hopkins - GIF images are downloaded.  Using XV 2 PPM ASCII files
%                    are created.  One of just the SST image itself, the other
%                    just the color portion of the colorbar.  The routines to
%                    process these files map them onto the HOPS horizontal grid.
%
%    SMAST ASCII - Already gridded onto HOPS horizontal grids.  Two versions
%                  of these files exist.  Those with standard deviations and
%                  data counts attached, and those without.
%
% For both sources, the SST is extended in the vertical.  The extension
% employed is a constant extension throughout the mixed layer.
%
% Error fields, corresponding to the SST fields are constructed.  In the
% horizontal, the nondimensional fields are chosen to be small where there
% is data and large where there is none.  The one exception is where a standard
% deviation is present, then that is scaled by the SST standard deviation.  In
% the vertical, the error field is increased (nonlinearly) in depth to an
% unassimilatable value at the base of the mixed layer.
%
% This package is NOT stand alone.  It requires that the HOPS PE_mask and
% Cond_topo directories be in the Matlab path.  (Possibly others too).
%
% This package is written to be included in your Matlab path.  Then processing
% an SST file only requires bringing a copy of the desired _.in file to the
% processing directory.

--------
Drivers:
--------

   sst2oa........Drives "mapping" of gridded ASCII SMAST SST onto a HOPS
                 OA(G)/FM netCDF file.  Reads from file with Std. Dev estimates.
   sst2oa_old....Drives "mapping" of gridded ASCII SMAST SST onto a HOPS
                 OA(G)/FM netCDF file.  Reads from file without Std. Dev
                 estimates.
   sst2pi........Drives "mapping" of gridded ASCII SMAST SST onto a HOPS
                 PE_initial (initialization) netCDF file.  Reads from file with
                 Std. Dev estimates.
   sstoa2piass...Maps SST from OA(G)/FM netCDF file to a PE_initial
                 (assimilation) netCDF file.
   sstppm2oa.....Drives "mapping" of pre-processed Johns Hopkins SST image, in
                 ASCII PPM format, onto a HOPS OA(G)/FM netCDF file.
   sstppm2pi.....Drives "mapping" of pre-processed Johns Hopkins SST image, in
                 ASCII PPM format, onto a HOPS PE_initial netCDF file.

-------------
Input/Output:
-------------

   read_flx2............Read windstress & net heatflux from PE_forcing output.
   read_ppm.............Read a PPM ASCII image data file.
   read_sst.............Read a gridded ASCII SMAST SST file without Std.Dev
                        estimates
   read_sst_flgg........Read a gridded ASCII SMAST SST file with Std.Dev
                        estimates.
   rep_oa...............Overwrite Temperature & Temperature Error contents of a
                        HOPS OA(G)/FM file with SST in estimated mixed layer.
   rep_pi...............Overwrite Temperature & Temperature Error contents of a
                        HOPS PE_initial file with SST in estimated mixed layer.
   sst2oa_inparm........Read run parameters for SST2OA or SST2OA_OLD.
   sst2pi_inparm........Read run parameters for SST2PI.
   sstoa2piass_inparm...Read run parameters for SSTOA2PIASS.
   sstppm2oa_inparm.....Read run parameters for SSTPPM2OA.
   sstppm2pi_inparm.....Read run parameters for SSTPPM2PI.

-----------
Processing:
-----------

   get_sst...........Drives mapping of pre-processed Johns Hopkins image to
                     HOPS grid.
   make_errbnd_msk...Constructs mask of width (n) around "bad" points.
                     Used to smooth error field.
   meansst...........Maps SST data to HOPS grid by taking median of points
                     surrounding each point.  Also computes Std Dev.
                     (Used for converting Johns Hopkins image)
   nearsst...........Maps SST data to HOPS grid by using nearest point.
                     (Used for converting Johns Hopkins image)
   smooth_err........Smooth error field transition from reliable to missing
                     data.
   smooth_under_iw...Smoothly extend data under a mask.  Used to fill missing
                     data.

-----------
Processing:
-----------

   plot_fld...Provides diagnostic plots.
