function msk = make_errbnd_msk (err,nrep);
%
% function msk = make_errbnd_msk (err,nrep);
%
% This function constructs an mask of point bounding high error.

%-------------------------------------------------------------------------------
% Construct working mask of high error locations.
%-------------------------------------------------------------------------------

[ny nx] = size (err);

wk = zeros(size(err));
ind = find (err>=1);
wk(ind) = 1;

rhs = reshape (wk,nx*ny,1);

%-------------------------------------------------------------------------------
% Construct summation matrix.
%-------------------------------------------------------------------------------

diag0     = ones (nx*ny,1);

diagp1    = ones (nx*ny,1);
diagpnym1 = ones (nx*ny,1);
diagpny   = ones (nx*ny,1);
diagpnyp1 = ones (nx*ny,1);

diagm1    = ones (nx*ny,1);
diagmnyp1 = ones (nx*ny,1);
diagmny   = ones (nx*ny,1);
diagmnym1 = ones (nx*ny,1);

%-------------------------------------------------------------------------------
% Apply summation operator.
%-------------------------------------------------------------------------------

%-------------------------------
%--- Assemble sparse matrix. ---
%-------------------------------

SumMat = spdiags ( [diagmnym1 diagmny diagmnyp1 ...
                    diagm1    diag0   diagp1    ...
                    diagpnym1 diagpny diagpnyp1 ], ...
                   [(-ny-1):(1-ny) -1:1 (ny-1):(ny+1)], ...
                   (nx*ny), (nx*ny) );

clear diagmnym1 diagmny diagmnyp1 ...
      diagm1    diag0   diagp1    ...
      diagpnym1 diagpny diagpnyp1;

SumMat = SumMat^nrep;

%------------------------------
%--- Solve matrix equation. ---
%------------------------------

soln = SumMat*rhs;

%----------------------------------
%--- Put answer in useful form. ---
%----------------------------------

wknew = reshape (soln,ny,nx);

%-------------------------------------------------------------------------------
% Find boundary points.
%-------------------------------------------------------------------------------

msk = ones(size(err));

ind = find ( (wknew~=0) & (wk==0) );
msk(ind) = 0;
