function [tlon,tlat,sst,sstdev,cnt] = ...
                              meansst (domdat,tlonfull,tlatfull,sstfull,dt);
%
% function [tlon,tlat,sst,sstdev,cnt] = ...
%                              meansst (domdat,tlonfull,tlatfull,sstfull,dt);
%
% This function averages an SST image onto a HOPS domain.  The average
% employed is the median, to limit the influence of outliers.

%-------------------------------------------------------------------------------
% Extract domain data.
%-------------------------------------------------------------------------------

coord = domdat( 1);
lonc  = domdat( 2);
latc  = domdat( 3);
theta = domdat( 4);
im    = domdat( 5);
jm    = domdat( 6);
dx    = domdat( 7);
dy    = domdat( 8);
delx  = domdat( 9);
dely  = domdat(10);

dt2 = dt.*dt;

%-------------------------------------------------------------------------------
% Grid SST data.
%-------------------------------------------------------------------------------

%------------------------------------------------
%--- Convert SST positions to Grid positions. ---
%------------------------------------------------

[Tlon Tlat] = meshgrid (tlonfull,tlatfull);

[isst,jsst]   = ll2xy (Tlon,Tlat,coord,im,jm,dx,dy,lonc,latc,delx, ...
                       dely,theta);

clear Tlon Tlat;

isst = round(isst);
jsst = round(jsst);

ind = find ( (isst<1) | (isst>im) | (jsst<1) | (jsst>jm) );
sstwk = sstfull;
if ~isempty(ind)
   sstwk(ind) = [];
   isst(ind)  = [];
   jsst(ind)  = [];
end

%------------------------------------
%--- Initialize output variables. ---
%------------------------------------

[X Y] = meshgrid ((1:im),(1:jm));

[tlon,tlat] = xy2ll (X,Y,coord,im,jm,dx,dy,lonc,latc,delx,dely,theta);

sst    = NaN.*ones(jm,im);
sstdev = NaN.*ones(jm,im);
cnt    = zeros(jm,im);

clear X Y;

%-----------------------------------------------------
%--- Loop over all grid positions, extracting SST. ---
%-----------------------------------------------------

for j = 1:jm
for i = 1:im

   ind = find ( (isst==i) & (jsst==j) );

   if ~isempty(ind)
      ssttmp     = sstwk(ind);
      sstwk(ind) = [];
      isst(ind)  = [];
      jsst(ind)  = [];
      rmind = find (isnan(ssttmp));
      if ~isempty(rmind)
         ssttmp(rmind) = [];
      end;
    else
      ssttmp = [];
   end;

   if ~isempty(ssttmp)
      sst(j,i) = median(ssttmp);
      npt      = length(ssttmp);
      cnt(j,i) = npt;
      if (npt>1)
         sstdev(j,i) = sqrt( sum((ssttmp-sst(j,i)).^2)./(npt-1) + dt2 );
      end;
   end;

end;
end;

clear i j ind rmind npt coord lonc latc theta im jm dx dy delx dely;
