function [tlon,tlat,sst,sstdev,cnt] = ...
                              nearsst (domdat,tlonfull,tlatfull,sstfull,dt);
%
% function [tlon,tlat,sst,sstdev,cnt] = ...
%                              nearsst (domdat,tlonfull,tlatfull,sstfull,dt);
%
% This function averages an SST image onto a HOPS domain.  The average
% employed is the median, to limit the influence of outliers.

%-------------------------------------------------------------------------------
% Extract domain data.
%-------------------------------------------------------------------------------

coord = domdat( 1);
lonc  = domdat( 2);
latc  = domdat( 3);
theta = domdat( 4);
im    = domdat( 5);
jm    = domdat( 6);
dx    = domdat( 7);
dy    = domdat( 8);
delx  = domdat( 9);
dely  = domdat(10);

%-------------------------------------------------------------------------------
% Extract image positioning data.
%-------------------------------------------------------------------------------

nsstx = length (tlonfull);
nssty = length (tlatfull);

dsstx = median(diff(tlonfull));
dssty = median(diff(tlatfull));

%-------------------------------------------------------------------------------
% Grid SST data.
%-------------------------------------------------------------------------------

%-----------------------------
%--- Compute grid lat/lon. ---
%-----------------------------

[X Y] = meshgrid ((1:im),(1:jm));

[tlon,tlat] = xy2ll (X,Y,coord,im,jm,dx,dy,lonc,latc,delx,dely,theta);

clear X Y;

%-------------------------------------------------------
%--- Locate nearest SST positions to Grid positions. ---
%-------------------------------------------------------

iind = round( (tlon-min(tlonfull))./dsstx ) + 1;
ind  = find (iind<1);
if ~isempty(ind)
   iind(ind) = 1;
end;
ind  = find (iind>nsstx);
if ~isempty(ind)
   iind(ind) = nsstx;
end;

jind = round( (tlat-min(tlatfull))./dssty ) + 1;
ind  = find (jind<1);
if ~isempty(ind)
   jind(ind) = 1;
end;
ind  = find (jind>nssty);
if ~isempty(ind)
   jind(ind) = nssty;
end;

%------------------------------------
%--- Initialize output variables. ---
%------------------------------------

sst    = NaN.*ones(jm,im);
sstdev = dt.*ones(jm,im);
cnt    = 2.*ones(jm,im);

%----------------------------------
%--- Extract nearest SST value. ---
%----------------------------------

ind = jind + (iind-1).*nssty;

sst = sstfull(ind);

%-------------------------------------------------------------------------------
% Keep track of data gaps.
%-------------------------------------------------------------------------------

ind = find (isnan(sst));

if ~isempty(ind)
   sstdev(ind) = NaN;
   cnt(ind)    = NaN;
end;

%-------------------------------------------------------------------------------
% Fill gaps.
%-------------------------------------------------------------------------------

wk  = sst;
msk = ones(size(wk));
ind = find(isnan(wk));
msk(ind) = 0;

sst = smooth_under3 (wk,msk);

%-------------------------------------------------------------------------------
% Smooth edges.
%-------------------------------------------------------------------------------

wk  = sst;
sst = shapiro2D (wk,2,3);
