function plot_fld (long,latg,Fld,clvls);
%
% function plot_fld (long,latg,Fld,clvls);
%
% This script creates a color map of
% the given field.

%-------------------------------------------------------------------------------
% Set default values.
%-------------------------------------------------------------------------------

if (nargin<4)
   clvls = [];
end;

%-------------------------------------------------------------------------------
% Determine MATLAB version number.
%-------------------------------------------------------------------------------

vstr = version;
vnum = str2num(vstr(1));

%-------------------------------------------------------------------------------
% Determine if the EXTCONTOUR package of Rich Pawlowicz is in the MATLAB path.
%-------------------------------------------------------------------------------

if (vnum<5),
   use_ext = exist('extcontour') == 2;
 else
   use_ext = 0;
end;

%-------------------------------------------------------------------------------
% Create new plot.
%-------------------------------------------------------------------------------

%clf;

%-------------------------------------------------------------------------------
% Select contour clvls to contain entire range of the field.
% Prevents holes in the color-filled contour map.  Only for EXTCONTOUR.
%-------------------------------------------------------------------------------

if ( (use_ext | (vnum>4)) & isempty(clvls) ),
   clvls=nice(extrem(Fld),4);
end;

%-------------------------------------------------------------------------------
% Draw the color-filled contour map.
%-------------------------------------------------------------------------------

if ( (vnum>4) & (diff(extrem(Fld))>0) ),

   [C,H,CF] = contourf (long,latg,Fld,clvls); ...
   set(gca,'XLim',[min(min(long)) max(max(long))], ...
           'YLim',[min(min(latg)) max(max(latg))], ...
           'FontName','Times','FontSize',14,'Box','On', ...
           'DataAspectRatio',[1 cos(mean(mean(latg))*pi/180) 1]);
   colormap(jet(length(clvls)+1)); ...
%   h=colorbarf_pjh(C,H,'vert',5); ...
   h=colorbar; ...
   set(h,'FontName','Times','FontSize',14);
   map=colormap;
   [cmin cmax] = caxis;
   [nmap nrgb] = size(map);
   hmap = [];
   for n = 1:length(H),
      hclr = get(H(n),'CData');
      if ~isnan(hclr),
         hmap = map(round(1+(nmap-1)/(cmax-cmin)*(hclr-cmin)),:);
         set (H(n),'EdgeColor',hmap);
        else
         if (~isempty(hmap)),
            set (H(n),'EdgeColor',hmap);
           else
            set (H(n),'EdgeColor',[1 1 1]);
         end;
      end;
   end;
   clear C H CF h hclr hmap map cmin cmax nmap nrgb n;

 elseif ( use_ext & (diff(extrem(Fld))>0) ),

   extcontour(long,latg,Fld,'fill'); ...
   set(gca,'XLim',[min(min(long)) max(max(long))], ...
           'YLim',[min(min(latg)) max(max(latg))], ...
           'FontName','Times', ...
           'AspectRatio',[1 cos(mean(mean(latg))*pi/180)]);
   caxis([clvls(1) clvls(length(clvls))]); ...
   colormap(jet(length(clvls)-1)); ...
   colorbar;

 elseif (diff(extrem(Fld))>0),

   pcolor (long,latg,Fld,-topo); ...
   set(gca,'XLim',[min(min(long)) max(max(long))], ...
           'YLim',[min(min(latg)) max(max(latg))], ...
           'FontName','Times', ...
           'AspectRatio',[1 cos(mean(mean(latg))*pi/180)]);
   shading interp; ...
   colormap (jet); ...
   colorbar;

 else

   [ny nx] = size(long);
   plot (long( 1, :),latg( 1, :),'k', ...
         long( :,nx),latg( :,nx),'k', ...
         long(ny, :),latg(ny, :),'k', ...
         long( :, 1),latg( :, 1),'k')
   set (gca,'XLim',[min(min(long)) max(max(long))], ...
            'YLim',[min(min(latg)) max(max(latg))], ...
            'FontName','Times','FontSize',14,'Box','On', ...
            'DataAspectRatio',[1 cos(mean(mean(latg))*pi/180) 1]);
   text (mean(long(:)),mean(latg(:)), ...
         ['Constant Value ',num2str(Fld(1))], ...
         'FontName','Times', ...
         'FontSize',18, ...
         'HorizontalAlignment','Center', ...
         'VerticalAlignment','Middle');
   clear nx ny;

end;
