function [red,green,blue,status] = read_ppm (file);
%
% function [red,green,blue,status] = read_ppm (file);
%
% This function reads in a PPM ASCII image data file
% and converts it to an RGB map.
% 
% ------
% Input:
% ------
% 
%    FILE.....Input file name.
% 
% -------
% Output:
% -------
% 
%    RED......Matrix of red pixel values.
%    GREEN....Matrix of green pixel values.
%    BLUE.....Matrix of blue pixel values.
%    STATUS...Exit status.  [0] no error  [other] error
%

%-------------------------------------------------------------------------------
% Open input file.
%-------------------------------------------------------------------------------

[fid message] = fopen(file,'r');

if (fid<0),
   disp (' ');
   disp ('***Error:  READ_PPM - unable to open input file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   disp (['           ',setstr(34),message,setstr(34)]);
   disp (' ');
   status = fid;
   return;
end;

%-------------------------------------------------------------------------------
% Read input file.
%-------------------------------------------------------------------------------

%-------------------------------
%--- Read header & comments. ---
%-------------------------------

s0=fgetl(fid);
s='#';
p='#';
while strcmp(s(1),p)
    s=fgetl(fid);
end

%---------------------------
%--- Extract dimensions. ---
%---------------------------

a = str2num(s);
nx = a(1);
ny = a(2);

%---------------------------
%--- Read color scaling. ---
%---------------------------

scale = fscanf(fid,'%d',1);

%-------------------
%--- Read image. ---
%-------------------

f = fscanf(fid,'%d');

%-------------------------------------------------------------------------------
% Close input file.
%-------------------------------------------------------------------------------

status = fclose(fid);

if (status<0),
   disp (' ');
   disp ('***Error:  READ_PPM - unable to close input file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   disp (' ');
   return;
end;

%-------------------------------------------------------------------------------
% Process image data.
%-------------------------------------------------------------------------------

f = reshape(f,3,length(f)/3);

red   = reshape(f(1,:),nx,ny)'./scale;
green = reshape(f(2,:),nx,ny)'./scale;
blue  = reshape(f(3,:),nx,ny)'./scale;
