function status = rep_pi (fldnam,temp,terrsm,zmld,jdate,smthrep,pifile);
%
% function status = rep_pi (fldnam,temp,terrsm,zmld,jdate,smthrep,pifile);
%
% This function replaces the Temperature field in an PE_initial
% file with the SST & error fields.

%-------------------------------------------------------------------------------
% Open netCDF file.
%-------------------------------------------------------------------------------

status = mexcdf ('setopts',0);

ncid = netcdf (pifile,'write');

if isempty(ncid)
   disp (' ');
   disp ('***Error:  REP_PI - unable to open PE_initial file:');
   disp (['           ',setstr(34),pifile,setstr(34)]);
   disp (' ');
   status = -1;
   return;
end;

%-------------------------------------------------------------------------------
% Determine number of vertical levels & the depths.
%-------------------------------------------------------------------------------

name = 'level';
nz = size(ncid(name));

if isempty(nz)
   disp (' ');
   disp (['***Error:  REP_PI - unable to read dimension ',setstr(34), ...
          name,setstr(34),' in PE_initial file:']);
   disp (['           ',setstr(34),pifile,setstr(34)]);
   disp (' ');
   status = -1;
   return;
end;

%-------------------------------------------------------------------------------
% Replace SST in upper levels.
%-------------------------------------------------------------------------------

ind = find ( ~isnan(temp) );

ncid{'time'}(1) = jdate;

for n = 1:nz;

   zwk = squeeze(ncid{'tgrid3'}(:,:,n,3));
   twk = squeeze(ncid{fldnam}(1,:,:,n));
   ind = find ( (abs(zwk)<=abs(zmld)) & ~isnan(temp) );

   if ~isempty(ind)
      twk(ind) = temp(ind);
      ncid{fldnam}(1,:,:,n) = twk;

      ewk = terrsm(ind);
      indwk = find(ewk>1);
      if ~isempty(indwk)
         ewk(indwk) = 1;
      end;

      wt = abs(zwk(ind)./zmld(ind));
      indwk = find (abs(zmld(ind))==0);
      if ~isempty(indwk)
         wt(indwk) = 1;
      end;
      wt = wt.^8;

      ewk = ewk.*(1-wt) + wt;

      twk = squeeze(ncid{[fldnam,'err']}(1,:,:,n));
      twk(ind) = ewk;
      msk = make_errbnd_msk (twk,smthrep);
      terrsm = smooth_under_iw (twk,msk);
      ncid{[fldnam,'err']}(1,:,:,n) = terrsm;

    else

      ncid{[fldnam,'err']}(1,:,:,n) = ...
                            ones(size(squeeze(ncid{[fldnam,'err']}(1,:,:,n))));

   end;

end;

%-------------------------------------------------------------------------------
% Close netCDF file.
%-------------------------------------------------------------------------------

status = close (ncid);

if ~isempty(status)
   disp (' ');
   disp ('***Error:  REP_PI - unable to close PE_initial file:');
   disp (['           ',setstr(34),pifile,setstr(34)]);
   disp (' ');
   status = -1;
   return;
end;

status = 0;
