function errnew = smooth_err (err,rep);
%
% function errnew = smooth_err (err,rep);
%
% This function smoothly extrapolates the given
% field under its mask.

%-------------------------------------------------------------------------------
% Initialize with identity matrix.
%-------------------------------------------------------------------------------

[ny nx] = size (err);
[jact iact] = find (~isnan(err) & (err<1));

rhs = reshape (err,nx*ny,1);
ind = find (isnan(rhs));
rhs(ind) = max([1 err(find(~isnan(err)))']);

diag0     = ones (nx*ny,1);

diagp1    = zeros (nx*ny,1);
diagpnym1 = zeros (nx*ny,1);
diagpny   = zeros (nx*ny,1);
diagpnyp1 = zeros (nx*ny,1);

diagm1    = zeros (nx*ny,1);
diagmnyp1 = zeros (nx*ny,1);
diagmny   = zeros (nx*ny,1);
diagmnym1 = zeros (nx*ny,1);

%-------------------------------------------------------------------------------
% Set Averaging operator under mask.
%-------------------------------------------------------------------------------

%-----------------
%--- SW corner ---
%-----------------

ind = find ((jact==1) & (iact==1));

if ~isempty(ind)
   indwk = iact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagp1(indwk+1)       = 0.25;
   diagpny(indwk+ny)     = 0.25;
   diagpnyp1(indwk+ny+1) = 0.25;
   jact(ind) = [];
   iact(ind) = [];
end;

%-----------------
%--- SE corner ---
%-----------------

ind = find ((jact==1) & (iact==nx));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagp1(indwk+1)       = 0.25;
   diagmny(indwk-ny)     = 0.25;
   diagmnyp1(indwk-ny+1) = 0.25;
   jact(ind) = [];
   iact(ind) = [];
end;

%-----------------
%--- NW corner ---
%-----------------

ind = find ((jact==ny) & (iact==1));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagm1(indwk-1)       = 0.25;
   diagpny(indwk+ny)     = 0.25;
   diagpnym1(indwk+ny-1) = 0.25;
   jact(ind) = [];
   iact(ind) = [];
end;

%-----------------
%--- NE corner ---
%-----------------

ind = find ((jact==ny) & (iact==nx));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagm1(indwk-1)       = 0.25;
   diagmny(indwk-ny)     = 0.25;
   diagmnym1(indwk-ny-1) = 0.25;
   jact(ind) = [];
   iact(ind) = [];
end;

%--------------
%--- W edge ---
%--------------

ind = find ((iact==1));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagm1(indwk-1)       = 0.125;
   diagp1(indwk+1)       = 0.125;
   diagpny(indwk+ny)     = 0.25;
   diagpnym1(indwk+ny-1) = 0.125;
   diagpnyp1(indwk+ny+1) = 0.125;
   jact(ind) = [];
   iact(ind) = [];
end;

%--------------
%--- E edge ---
%--------------

ind = find ((iact==nx));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagm1(indwk-1)       = 0.125;
   diagp1(indwk+1)       = 0.125;
   diagmny(indwk-ny)     = 0.25;
   diagmnym1(indwk-ny-1) = 0.125;
   diagmnyp1(indwk-ny+1) = 0.125;
   jact(ind) = [];
   iact(ind) = [];
end;

%--------------
%--- S edge ---
%--------------

ind = find ((jact==1));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagp1(indwk+1)       = 0.25;
   diagmny(indwk-ny)     = 0.125;
   diagpny(indwk+ny)     = 0.125;
   diagmnyp1(indwk-ny+1) = 0.125;
   diagpnyp1(indwk+ny+1) = 0.125;
   jact(ind) = [];
   iact(ind) = [];
end;

%--------------
%--- N edge ---
%--------------

ind = find ((jact==ny));

if ~isempty(ind)
   indwk = jact(ind) + (iact(ind)-1)*ny;
   diag0(indwk)          = 0.25;
   diagm1(indwk-1)       = 0.25;
   diagmny(indwk-ny)     = 0.125;
   diagpny(indwk+ny)     = 0.125;
   diagmnym1(indwk-ny-1) = 0.125;
   diagpnym1(indwk+ny-1) = 0.125;
   jact(ind) = [];
   iact(ind) = [];
end;

%----------------
%--- Interior ---
%----------------

indwk = jact + (iact-1)*ny;
diag0(indwk)          = 0.25;
diagm1(indwk-1)       = 0.125;
diagp1(indwk+1)       = 0.125;
diagmny(indwk-ny)     = 0.125;
diagpny(indwk+ny)     = 0.125;
diagmnym1(indwk-ny-1) = 0.0625;
diagpnym1(indwk+ny-1) = 0.0625;
diagmnyp1(indwk-ny+1) = 0.0625;
diagpnyp1(indwk+ny+1) = 0.0625;

clear ind indwk iact jact;

%-------------------------------------------------------------------------------
% Apply averaging operator.
%-------------------------------------------------------------------------------

%-------------------------------
%--- Assemble sparse matrix. ---
%-------------------------------

ExtMat = spdiags ( [diagmnym1 diagmny diagmnyp1 ...
                    diagm1    diag0   diagp1    ...
                    diagpnym1 diagpny diagpnyp1 ], ...
                   [(-ny-1):(1-ny) -1:1 (ny-1):(ny+1)], ...
                   (nx*ny), (nx*ny) );

clear diagmnym1 diagmny diagmnyp1 ...
      diagm1    diag0   diagp1    ...
      diagpnym1 diagpny diagpnyp1;

%--------------------------------------
%--- Set for number of repetitions. ---
%--------------------------------------

ExtMat = ExtMat^rep;

%---------------------------------
%--- Apply averaging operator. ---
%---------------------------------

soln = ExtMat*rhs;

%----------------------------------
%--- Put answer in useful form. ---
%----------------------------------

errnew = reshape (soln,ny,nx);
