% sstoa2piass
%
% This script maps Objectively Analyzed SST onto a PE_initial assimilation file.

%-------------------------------------------------------------------------------
% Get run parameters.
%-------------------------------------------------------------------------------

infiledef = 'sstoa2piass.in';

infile = input (['Enter name for parameter input file [',infiledef,']: '],'s');

if isempty(infile)
   infile = infiledef;
end;

clear infiledef

[smthrep,combflg,ekfac,frcfile,oafile,pifile,status] = ...
                          sstoa2piass_inparm (infile);

if (status<0)
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read parameter input file:');
   disp (['           ',setstr(34),infile,setstr(34)]);
   return;
end;

clear infile status

%-------------------------------------------------------------------------------
% Set useful parameters.
%-------------------------------------------------------------------------------

cm2m       = 0.01;

%-------------------------------------------------------------------------------
% Read in data.
%-------------------------------------------------------------------------------

%----------------
%--- Get SST. ---
%----------------

status = mexcdf ('setopts',0);

ncid = netcdf (oafile,'nowrite');

if isempty(ncid),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to open OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

jdate = ncid{'time'}(1);

if isempty(jdate),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

lon = ncid{'grid3'}(:,:,1);

if isempty(lon),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

lat = ncid{'grid3'}(:,:,2);

if isempty(lat),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

temp = ncid{'temp'}(1,:,:,1);

if isempty(temp),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

terr = ncid{'temperr'}(1,:,:,1);

if isempty(temp),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

trms = ncid{'temprmsdev'}(1,1);

if isempty(temp),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to read OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

status = close (ncid);

if ~isempty(status),
   disp (' ');
   disp ('***Error:  SSTOA2PIASS - unable to close OA(G) file');
   disp(['           ',setstr(34),oafile,setstr(34)]);
   disp (' ');
   return;
end;

clear status;

%---------------------------
%--- Get surface fluxes. ---
%---------------------------

[HeatFlux,WindStress,status] = read_flx2 (frcfile,jdate);

if (status<0),
   disp (' ');
   disp ('***Error:  SST2OA - unable to read forcing file');
   disp(['           ',setstr(34),frcfile,setstr(34)]);
   disp (' ');
   return;
end;

%-------------------------------------------------------------------------------
% Construct mixed layer depths.
%-------------------------------------------------------------------------------

zmld  = ekfac.*WindStress.*cm2m;

%-------------------------------------------------------------------------------
% Construct SST errors.
%-------------------------------------------------------------------------------

%--------------------------------------------------
%--- Scale Standard Deviations by SST variance. ---
%--------------------------------------------------

terr = (terr./trms).^2;

%-------------------------------------------------------------------------------
% Place SST into OA(G)/FM file.
%-------------------------------------------------------------------------------

if (combflg)
%   status = comb_pi ('temp',temp,terr,zmld,jdate,smthrep,pifile);
   disp (' ');
   disp ('************************************************');
   disp ('***     Combination option not yet coded.    ***');
   disp ('*** PE_initial file will not be overwritten. ***');
   disp ('************************************************');
   disp (' ');
 else
   status = rep_pi ('temp',temp,terr,zmld,jdate,smthrep,pifile);
end;

if (status<0)
   disp (' ');
   disp ('***Error:  SST2OA - unable to place SST into OA(G)/FM file:');
   disp (['           ',setstr(34),oafile,setstr(34)]);
   return;
end;

clear pifile;

%-------------------------------------------------------------------------------
% Plot SST.
%-------------------------------------------------------------------------------

cstfile = '/home/haley/Oceanplot/Coast_data/gulf_cst.dat';
[clon,clat] = rcoastline (cstfile);
clear cstfile;

plot_fld (lon,lat,temp,[]);

title (['Sea Surface Temperature (^oC)  [', ...
        num2str(extrem(temp(find(~isnan(temp))))),']']);
h=suptitle(oafile);
set(h,'Interpreter','None','FontName','Times','FontSize',14);
hold on;
h = fill_cst (clon,clat,[0.9 0.9 0.9],[0.5 0.5 0.5]);

%-------------------------------------------------------------------------------
% Plot Error Field.
%-------------------------------------------------------------------------------

figure;
plot_fld (lon,lat,terr,[]);

title (['NonDimensional Error  [', ...
        num2str(extrem(terr(find(~isnan(terr))))),']']);
h=suptitle(oafile);
set(h,'Interpreter','None','FontName','Times','FontSize',14);
hold on;
h = fill_cst (clon,clat,[0.9 0.9 0.9],[0.5 0.5 0.5]);

%-------------------------------------------------------------------------------
% Plot Mixed Layer Depth Field.
%-------------------------------------------------------------------------------

figure;
plot_fld (lon,lat,zmld,[]);

title (['Mixed Layer Depth  (m)  [',num2str(extrem(zmld(:))),']']);
h=suptitle(frcfile);
set(h,'Interpreter','None','FontName','Times','FontSize',14);
hold on;
h = fill_cst (clon,clat,[0.9 0.9 0.9],[0.5 0.5 0.5]);
